@@ -21,6 +21,8 @@ from typing import Any
 
 from pydantic import Field
 from typing_extensions import override
+from vikingdb import IAM
+from vikingdb.memory import VikingMem
 
 import veadk.config  # noqa E401
 from veadk.auth.veauth.utils import get_credential_from_vefaas_iam
@@ -46,10 +48,34 @@ class VikingDBLTMBackend(BaseLongTermMemoryBackend):
 
     session_token: str = ""
 
-    region: str = "cn-beijing"
+    region: str = Field(
+        default_factory=lambda: os.getenv("DATABASE_VIKINGMEM_REGION") or "cn-beijing"
+    )
     """VikingDB memory region"""
 
+    volcengine_project: str = Field(
+        default_factory=lambda: os.getenv("DATABASE_VIKINGMEM_PROJECT") or "default"
+    )
+    """VikingDB memory project"""
+
+    memory_type: list[str] = Field(default_factory=list)
+
     def model_post_init(self, __context: Any) -> None:
+        # We get memory type from:
+        # 1. user input
+        # 2. environment variable
+        # 3. default value
+        if not self.memory_type:
+            env_memory_type = os.getenv("DATABASE_VIKINGMEM_MEMORY_TYPE")
+            if env_memory_type:
+                # "event_1, event_2" -> ["event_1", "event_2"]
+                self.memory_type = [x.strip() for x in env_memory_type.split(",")]
+            else:
+                # self.memory_type = ["sys_event_v1", "event_v1"]
+                self.memory_type = ["sys_event_v1"]
+
+        logger.info(f"Using memory type: {self.memory_type}")
+
         # check whether collection exist, if not, create it
         if not self._collection_exist():
             self._create_collection()
@@ -67,18 +93,27 @@ class VikingDBLTMBackend(BaseLongTermMemoryBackend):
     def _collection_exist(self) -> bool:
         try:
             client = self._get_client()
-            client.get_collection(collection_name=self.index)
+            client.get_collection(
+                collection_name=self.index, project=self.volcengine_project
+            )
+            logger.info(f"Collection {self.index} exist.")
             return True
         except Exception:
+            logger.info(f"Collection {self.index} not exist.")
             return False
 
     def _create_collection(self) -> None:
+        logger.info(
+            f"Create collection with collection_name={self.index}, builtin_event_types={self.memory_type}"
+        )
         client = self._get_client()
         response = client.create_collection(
             collection_name=self.index,
+            project=self.volcengine_project,
             description="Created by Volcengine Agent Development Kit VeADK",
-            builtin_event_types=["sys_event_v1"],
+            builtin_event_types=self.memory_type,
         )
+        logger.debug(f"Create collection with response {response}")
         return response
 
     def _get_client(self) -> VikingDBMemoryClient:
@@ -95,8 +130,21 @@ class VikingDBLTMBackend(BaseLongTermMemoryBackend):
             region=self.region,
         )
 
+    def _get_sdk_client(self) -> VikingMem:
+        client = self._get_client()
+        return VikingMem(
+            host=client.get_host(),
+            region=self.region,
+            auth=IAM(
+                ak=self.volcengine_access_key,
+                sk=self.volcengine_secret_key,
+            ),
+            sts_token=self.session_token,
+        )
+
     @override
     def save_memory(self, user_id: str, event_strings: list[str], **kwargs) -> bool:
+        assistant_id = kwargs.get("assistant_id", "assistant")
         session_id = str(uuid.uuid1())
         messages = []
         for raw_events in event_strings:
@@ -108,7 +156,7 @@ class VikingDBLTMBackend(BaseLongTermMemoryBackend):
             messages.append({"role": role, "content": content})
         metadata = {
             "default_user_id": user_id,
-            "default_assistant_id": "assistant",
+            "default_assistant_id": assistant_id,
             "time": int(time.time() * 1000),
         }
 
@@ -116,12 +164,14 @@ class VikingDBLTMBackend(BaseLongTermMemoryBackend):
             f"Request for add {len(messages)} memory to VikingDB: collection_name={self.index}, metadata={metadata}, session_id={session_id}"
         )
 
-        client = self._get_client()
-        response = client.add_messages(
-            collection_name=self.index,
+        client = self._get_sdk_client()
+        collection = client.get_collection(
+            collection_name=self.index, project_name=self.volcengine_project
+        )
+        response = collection.add_session(
+            session_id=session_id,
             messages=messages,
             metadata=metadata,
-            session_id=session_id,
         )
 
         logger.debug(f"Response from add memory to VikingDB: {response}")
@@ -135,18 +185,20 @@ class VikingDBLTMBackend(BaseLongTermMemoryBackend):
     def search_memory(
         self, user_id: str, query: str, top_k: int, **kwargs
     ) -> list[str]:
-        filter = {
-            "user_id": user_id,
-            "memory_type": ["sys_event_v1", "event_v1"],
-        }
+        filter = {"user_id": user_id, "memory_type": self.memory_type}
 
         logger.debug(
             f"Request for search memory in VikingDB: filter={filter}, collection_name={self.index}, query={query}, limit={top_k}"
         )
 
-        client = self._get_client()
-        response = client.search_memory(
-            collection_name=self.index, query=query, filter=filter, limit=top_k
+        client = self._get_sdk_client()
+        collection = client.get_collection(
+            collection_name=self.index, project_name=self.volcengine_project
+        )
+        response = collection.search_memory(
+            query=query,
+            filter=filter,
+            limit=top_k,
         )
 
         logger.debug(f"Response from search memory in VikingDB: {response}")
